@@ -29,7 +29,7 @@
 #include"postgres-functions.h"
 #include"boleta.h"
 #include"vale.h"
-
+#include<rizoma_errors.h>
 #include"config_file.h"
 
 gchar *
@@ -104,7 +104,8 @@ EjecutarSQL (gchar *sentencia)
 {
   PGconn *conection;
   PGresult *res;
-  
+  ConnStatusType status;
+
   char *host = rizoma_get_value (rizoma_config, "SERVER_HOST");
   char *name = rizoma_get_value (rizoma_config, "DB_NAME");
   char *user = rizoma_get_value (rizoma_config, "USER");
@@ -113,11 +114,21 @@ EjecutarSQL (gchar *sentencia)
   conection = PQconnectdb 
     (g_strdup_printf ("host=%s dbname=%s user=%s password=%s sslmode=require", host, name, user, pass));
 
-  res = PQexec (conection, sentencia);
+  status = PQstatus(conection);
 
-  PQfinish (conection);
-  
-  return res;
+  switch (status)
+    {
+    case CONNECTION_OK:
+      res = PQexec (conection, sentencia);
+      PQfinish (conection);
+      return res;
+      break;
+    case CONNECTION_BAD:
+      rizoma_errors_set (PQerrorMessage (conection), "EjcutarSQL ()", ERROR);
+      return NULL;
+    default:
+      return NULL;
+    }
 }
 
 gboolean
@@ -751,8 +762,9 @@ SaveBuyProducts (Productos *header, gint id_compra)
   do 
     {    
       
-      iva = (gdouble) (products->product->precio_compra * products->product->cantidad) * 
-	(gdouble)products->product->iva / 100;
+      if (products->product->iva != -1)
+	iva = (gdouble) (products->product->precio_compra * products->product->cantidad) * 
+	  (gdouble)products->product->iva / 100;
       
       if (products->product->otros != -1)
 	otros = (gdouble) (products->product->precio_compra * products->product->cantidad) * 
