@@ -68,8 +68,8 @@ BuscarProveedor (GtkWidget *widget, gpointer data)
   gint tuples, i;
   gchar *string = g_strdup (gtk_entry_get_text (GTK_ENTRY (search_entry)));
   
-  res = EjecutarSQL (g_strdup_printf ("SELECT * FROM proveedores WHERE nombre LIKE '%%%s%%' "
-				      "OR rut LIKE '%%%s%%'", string, string));
+  res = EjecutarSQL (g_strdup_printf ("SELECT * FROM proveedores WHERE lower(nombre) LIKE lower('%%%s%%') "
+				      "OR lower(rut) LIKE lower('%%%s%%')", string, string));
 
   tuples = PQntuples (res);
 
@@ -81,6 +81,8 @@ BuscarProveedor (GtkWidget *widget, gpointer data)
       gtk_tree_store_set (GTK_TREE_STORE (proveedores_store), &iter,
 			  0, PQgetvalue (res, i, 1),
 			  1, PQgetvalue (res, i, 2),
+			  2, PQgetvalue (res, i, 10),
+			  3, PQgetvalue (res, i, 9),
 			  -1);
     }
   
@@ -105,6 +107,8 @@ ListarProveedores (void)
       gtk_tree_store_set (GTK_TREE_STORE (proveedores_store), &iter,
 			  0, PQgetvalue (res, i, 1),
 			  1, PQgetvalue (res, i, 2),
+			  2, PQgetvalue (res, i, 10),
+			  3, PQgetvalue (res, i, 9),			  
 			  -1);
     }  
 }
@@ -464,16 +468,16 @@ AgregarProveedorWindow (GtkWidget *widget, gpointer user_data)
 void 
 ModificarProveedor (void)
 {
-  gchar *rut_c = gtk_label_get_text (GTK_LABEL (rut));
-  gchar *razon_c = gtk_entry_get_text (GTK_ENTRY (razon));
-  gchar *direccion_c = gtk_entry_get_text (GTK_ENTRY (direccion));
-  gchar *comuna_c = gtk_entry_get_text (GTK_ENTRY (comuna));
-  gchar *ciudad_c = gtk_entry_get_text (GTK_ENTRY (ciudad));
-  gchar *fono_c = gtk_entry_get_text (GTK_ENTRY (fono));
-  gchar *web_c = gtk_entry_get_text (GTK_ENTRY (web));
-  gchar *contacto_c = gtk_entry_get_text (GTK_ENTRY (contacto));
-  gchar *email_c = gtk_entry_get_text (GTK_ENTRY (email));
-  gchar *giro_c = gtk_entry_get_text (GTK_ENTRY (giro));
+  gchar *rut_c = (gchar *) gtk_label_get_text (GTK_LABEL (rut));
+  gchar *razon_c = (gchar *) gtk_entry_get_text (GTK_ENTRY (razon));
+  gchar *direccion_c = (gchar *) gtk_entry_get_text (GTK_ENTRY (direccion));
+  gchar *comuna_c = (gchar *) gtk_entry_get_text (GTK_ENTRY (comuna));
+  gchar *ciudad_c = (gchar *) gtk_entry_get_text (GTK_ENTRY (ciudad));
+  gchar *fono_c = (gchar *) gtk_entry_get_text (GTK_ENTRY (fono));
+  gchar *web_c = (gchar *) gtk_entry_get_text (GTK_ENTRY (web));
+  gchar *contacto_c = (gchar *) gtk_entry_get_text (GTK_ENTRY (contacto));
+  gchar *email_c = (gchar *) gtk_entry_get_text (GTK_ENTRY (email));
+  gchar *giro_c = (gchar *) gtk_entry_get_text (GTK_ENTRY (giro));
 
   SetModificacionesProveedor (rut_c, razon_c, direccion_c, comuna_c, ciudad_c, fono_c,
 			      web_c, contacto_c, email_c, giro_c);
@@ -542,7 +546,9 @@ proveedores_box (GtkWidget *main_box)
 				  GTK_POLICY_AUTOMATIC);
   gtk_box_pack_start (GTK_BOX (hbox), scroll, FALSE, FALSE, 3);
   
-  proveedores_store = gtk_tree_store_new (2,
+  proveedores_store = gtk_tree_store_new (4,
+					  G_TYPE_STRING,
+					  G_TYPE_STRING,
 					  G_TYPE_STRING,
 					  G_TYPE_STRING);
 
@@ -568,6 +574,20 @@ proveedores_box (GtkWidget *main_box)
 						     NULL);
   gtk_tree_view_append_column (GTK_TREE_VIEW (proveedores_tree), column);
   gtk_tree_view_column_set_resizable (column, FALSE); 
+  
+  renderer = gtk_cell_renderer_text_new ();
+  column = gtk_tree_view_column_new_with_attributes ("Giro", renderer,
+						     "text", 2,
+						     NULL);
+  gtk_tree_view_append_column (GTK_TREE_VIEW (proveedores_tree), column);
+  gtk_tree_view_column_set_resizable (column, FALSE); 
+
+  renderer = gtk_cell_renderer_text_new ();
+  column = gtk_tree_view_column_new_with_attributes ("Contacto", renderer,
+						     "text", 3,
+						     NULL);
+  gtk_tree_view_append_column (GTK_TREE_VIEW (proveedores_tree), column);
+  gtk_tree_view_column_set_resizable (column, FALSE);
 
   frame = gtk_frame_new ("Proveedores");
   gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 3);
